"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.CreateComment = void 0;
const tslib_1 = require("tslib");
const Button_1 = tslib_1.__importDefault(require("@material-ui/core/Button/Button"));
const FormControl_1 = tslib_1.__importDefault(require("@material-ui/core/FormControl/FormControl"));
const FormHelperText_1 = tslib_1.__importDefault(require("@material-ui/core/FormHelperText/FormHelperText"));
const IconButton_1 = tslib_1.__importDefault(require("@material-ui/core/IconButton/IconButton"));
const InputAdornment_1 = tslib_1.__importDefault(require("@material-ui/core/InputAdornment/InputAdornment"));
const createStyles_1 = tslib_1.__importDefault(require("@material-ui/core/styles/createStyles"));
const makeStyles_1 = tslib_1.__importDefault(require("@material-ui/core/styles/makeStyles"));
const TextField_1 = tslib_1.__importDefault(require("@material-ui/core/TextField/TextField"));
const Tooltip_1 = tslib_1.__importDefault(require("@material-ui/core/Tooltip"));
const react_1 = tslib_1.__importStar(require("react"));
const hooks_1 = require("../../hooks");
const _1 = require(".");
const useStyles = makeStyles_1.default((theme) => {
    return createStyles_1.default({
        buttonContainer: {
            display: 'flex',
            flexDirection: 'row-reverse',
        },
        form: {
            width: '100%',
            display: 'flex',
        },
        activePin: {
            color: theme.palette.primary.light,
        },
    });
});
/**
 * Represents a comment creator component
 */
function CreateComment() {
    var _a, _b;
    const classes = useStyles();
    const [errorMessage, setErrorMessage] = react_1.useState();
    const [createCommentValue, setCreateCommentValue] = react_1.useState('');
    const localization = hooks_1.useLocalization();
    const commentState = hooks_1.useCommentState();
    const viewerState = hooks_1.useViewerState();
    const api = hooks_1.useDocumentViewerApi();
    const { documentData } = hooks_1.useDocumentData();
    const pageRotation = ((_b = (_a = viewerState.rotation) === null || _a === void 0 ? void 0 : _a.find((rotation) => rotation.pageNum === viewerState.activePage)) === null || _b === void 0 ? void 0 : _b.degree) || 0;
    const createComment = react_1.useCallback((text) => {
        if (!commentState.draft) {
            return;
        }
        try {
            api.commentActions.addPreviewComment({
                document: documentData,
                comment: Object.assign(Object.assign({}, commentState.draft), { text, page: viewerState.activePage }),
                abortController: new AbortController(),
            });
        }
        catch (error) {
            console.log(error);
        }
    }, [api.commentActions, commentState.draft, documentData, viewerState]);
    const clearState = react_1.useCallback(() => {
        commentState.setDraft(undefined);
        viewerState.updateState({
            isPlacingCommentMarker: false,
            isCreateCommentActive: !viewerState.isCreateCommentActive,
        });
        setCreateCommentValue('');
        setErrorMessage(undefined);
    }, [commentState, viewerState]);
    const validate = react_1.useCallback(() => {
        if (!createCommentValue) {
            return localization.inputRequiredError;
        }
        if (!commentState.draft) {
            return localization.markerRequiredError;
        }
        return undefined;
    }, [commentState.draft, createCommentValue, localization.inputRequiredError, localization.markerRequiredError]);
    const handleSubmit = react_1.useCallback((event) => {
        event.preventDefault();
        const errorText = validate();
        if (errorText) {
            setErrorMessage(errorText);
            return;
        }
        createComment(createCommentValue);
        clearState();
    }, [clearState, createComment, createCommentValue, validate]);
    const handleOnChange = (e) => {
        setCreateCommentValue(e.target.value);
        setErrorMessage(undefined);
    };
    if (!viewerState.isCreateCommentActive) {
        return (react_1.default.createElement(Button_1.default, { disabled: pageRotation !== 0, color: "primary", onClick: () => viewerState.updateState({ isCreateCommentActive: !viewerState.isCreateCommentActive }) }, localization.addComment));
    }
    return (react_1.default.createElement("form", { className: classes.form, onSubmit: handleSubmit },
        react_1.default.createElement(FormControl_1.default, { fullWidth: true, error: !!errorMessage },
            react_1.default.createElement(TextField_1.default, { id: "comment-input", multiline: true, label: localization.commentInputPlaceholder, margin: "normal", variant: "filled", value: createCommentValue, onChange: handleOnChange, InputProps: {
                    endAdornment: (react_1.default.createElement(InputAdornment_1.default, { position: "end" },
                        react_1.default.createElement(Tooltip_1.default, { placement: "top", title: localization.markerTooltip },
                            react_1.default.createElement(IconButton_1.default, { "aria-label": "Toggle", onClick: () => viewerState.updateState({ isPlacingCommentMarker: !viewerState.isPlacingCommentMarker }) },
                                react_1.default.createElement(_1.PushPinIcon, { isPlacingMarker: viewerState.isPlacingCommentMarker, viewBox: "0 0 100 125" }))))),
                } }),
            errorMessage ? react_1.default.createElement(FormHelperText_1.default, { id: "component-error-text" }, errorMessage) : null,
            react_1.default.createElement("div", { className: classes.buttonContainer },
                react_1.default.createElement(Button_1.default, { style: { alignSelf: 'flex-end' }, fullWidth: false, color: "primary", variant: "text", type: "submit" }, localization.submit),
                react_1.default.createElement(Button_1.default, { onClick: clearState, style: { alignSelf: 'flex-end' }, fullWidth: false, variant: "text" }, localization.cancelButton)))));
}
exports.CreateComment = CreateComment;
//# sourceMappingURL=create-comment.js.map