"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.DocumentViewerLayout = exports.PAGE_CONTAINER_ID = exports.PAGE_NAME = exports.PAGE_PADDING = exports.THUMBNAIL_CONTAINER_ID = exports.THUMBNAIL_NAME = exports.THUMBNAIL_PADDING = void 0;
const tslib_1 = require("tslib");
const Drawer_1 = tslib_1.__importDefault(require("@material-ui/core/Drawer"));
const createStyles_1 = tslib_1.__importDefault(require("@material-ui/core/styles/createStyles"));
const makeStyles_1 = tslib_1.__importDefault(require("@material-ui/core/styles/makeStyles"));
const Typography_1 = tslib_1.__importDefault(require("@material-ui/core/Typography"));
const react_1 = tslib_1.__importStar(require("react"));
const comments_1 = require("../context/comments");
const hooks_1 = require("../hooks");
const comment_1 = require("./comment");
const _1 = require("./");
exports.THUMBNAIL_PADDING = 16;
exports.THUMBNAIL_NAME = 'Thumbnail';
exports.THUMBNAIL_CONTAINER_ID = 'sn-document-viewer-thumbnails';
exports.PAGE_PADDING = 8;
exports.PAGE_NAME = 'Page';
exports.PAGE_CONTAINER_ID = 'sn-document-viewer-pages';
const useStyles = makeStyles_1.default(() => {
    return createStyles_1.default({
        mainWrapper: {
            width: '100%',
            height: '100%',
            display: 'flex',
            flexDirection: 'column',
            flexGrow: 1,
        },
        layout: {
            display: 'flex',
            flexGrow: 1,
            width: '100%',
            overflow: 'hidden',
            zIndex: 0,
            position: 'relative',
        },
        commentContainer: {
            display: 'flex',
            flexFlow: 'column',
            padding: '15px',
            justifyContent: 'space-between',
            alignItems: 'center',
            overflow: 'auto',
        },
    });
});
const DocumentViewerLayout = () => {
    const classes = useStyles();
    const viewerState = hooks_1.useViewerState();
    const localization = hooks_1.useLocalization();
    const viewerSettings = hooks_1.useViewerSettings();
    const scrollToImage = react_1.useCallback(({ containerId, index, itemName, padding, smoothScroll }) => {
        const container = document.getElementById(containerId);
        const item = document.querySelector(`.${itemName}`);
        if (container && container.scrollTo && item) {
            container.scrollTo({
                top: (item.clientHeight + padding * 4) * (index - 1),
                behavior: smoothScroll ? 'smooth' : 'auto',
            });
        }
    }, []);
    const scrollTo = react_1.useCallback((index, smoothScroll = true) => {
        scrollToImage({
            containerId: exports.PAGE_CONTAINER_ID,
            itemName: exports.PAGE_NAME,
            padding: exports.PAGE_PADDING,
            index,
            smoothScroll,
        });
        scrollToImage({
            containerId: exports.THUMBNAIL_CONTAINER_ID,
            itemName: exports.THUMBNAIL_NAME,
            padding: exports.THUMBNAIL_PADDING,
            index,
            smoothScroll,
        });
    }, [scrollToImage]);
    react_1.useEffect(() => {
        const observer = viewerState.pageToGo.subscribe(({ page }) => {
            scrollTo(page);
        });
        return () => observer.dispose();
    }, [scrollTo, viewerState.pageToGo]);
    return (react_1.default.createElement("div", { className: classes.mainWrapper },
        viewerSettings.renderAppBar(),
        react_1.default.createElement("div", { className: classes.layout },
            react_1.default.createElement(Drawer_1.default, { variant: 'persistent', open: viewerState.showThumbnails, anchor: "left", SlideProps: viewerSettings.drawerSlideProps, PaperProps: {
                    style: {
                        position: 'relative',
                        width: viewerState.showThumbnails ? '200px' : 0,
                        height: '100%',
                        overflow: 'hidden',
                    },
                } }, viewerState.showThumbnails && react_1.default.createElement(_1.Thumbnails, { onPageClick: (index) => scrollTo(index) })),
            react_1.default.createElement(_1.PageList, { onPageClick: (index) => scrollTo(index) }),
            react_1.default.createElement(Drawer_1.default, { variant: 'persistent', open: viewerState.showComments, anchor: "right", SlideProps: viewerSettings.drawerSlideProps, PaperProps: {
                    style: {
                        position: 'relative',
                        width: viewerState.showComments ? '340px' : 0,
                        height: '100%',
                        overflow: 'hidden',
                    },
                } },
                react_1.default.createElement("div", { className: classes.commentContainer },
                    react_1.default.createElement(Typography_1.default, { variant: "h4" }, localization.commentSideBarTitle),
                    react_1.default.createElement(comment_1.CreateComment, null),
                    react_1.default.createElement(comments_1.CommentsContext.Consumer, null, (commentsContext) => commentsContext.comments.map((comment) => react_1.default.createElement(comment_1.Comment, { key: comment.id, comment: comment }))))))));
};
exports.DocumentViewerLayout = DocumentViewerLayout;
//# sourceMappingURL=document-viewer-layout.js.map