"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.DocumentTitlePager = void 0;
const tslib_1 = require("tslib");
const ClickAwayListener_1 = tslib_1.__importDefault(require("@material-ui/core/ClickAwayListener"));
const createStyles_1 = tslib_1.__importDefault(require("@material-ui/core/styles/createStyles"));
const makeStyles_1 = tslib_1.__importDefault(require("@material-ui/core/styles/makeStyles"));
const TextField_1 = tslib_1.__importDefault(require("@material-ui/core/TextField"));
const Typography_1 = tslib_1.__importDefault(require("@material-ui/core/Typography"));
const react_1 = tslib_1.__importStar(require("react"));
const hooks_1 = require("../../hooks");
const useStyles = makeStyles_1.default(() => {
    return createStyles_1.default({
        typography: {
            cursor: 'pointer',
            display: 'flex',
            alignItems: 'center',
            overflow: 'hidden',
            margin: '0 2.5em',
        },
        nameWrapper: {
            whiteSpace: 'nowrap',
            overflow: 'hidden',
            textOverflow: 'ellipsis',
        },
        textField: {
            flexShrink: 0,
        },
        notFocusedText: {
            flexShrink: 0,
        },
    });
});
/**
 * Document widget component for paging
 */
const DocumentTitlePager = (props) => {
    const classes = useStyles(props);
    const { documentData } = hooks_1.useDocumentData();
    const viewerState = hooks_1.useViewerState();
    const localization = hooks_1.useLocalization();
    const [isFocused, setIsFocused] = react_1.useState(false);
    const [currentValue, setCurrentValue] = react_1.useState(viewerState.activePage);
    const gotoPage = (page) => {
        let pageInt = typeof page === 'string' ? parseInt(page, 10) : page;
        if (!isNaN(pageInt)) {
            pageInt = Math.max(pageInt, 1);
            pageInt = Math.min(pageInt, documentData.pageCount);
            viewerState.pageToGo.setValue({ page: pageInt });
        }
    };
    return (react_1.default.createElement(ClickAwayListener_1.default, { onClickAway: () => setIsFocused(false) },
        react_1.default.createElement(Typography_1.default, { onClick: () => setIsFocused(true), variant: "h6", color: "inherit", title: documentData.documentName, className: classes.typography },
            react_1.default.createElement("div", { className: classes.nameWrapper },
                documentData.documentName,
                "\u00A0"),
            isFocused ? (react_1.default.createElement("form", { onSubmit: (ev) => {
                    gotoPage(currentValue);
                    ev.preventDefault();
                } },
                react_1.default.createElement(TextField_1.default, { className: classes.textField, title: localization.gotoPage, onChange: (ev) => setCurrentValue(ev.currentTarget.value), onBlur: () => gotoPage(currentValue), defaultValue: viewerState.activePage, type: "number", required: true, InputLabelProps: {
                        shrink: true,
                    }, inputProps: {
                        min: 1,
                        max: documentData.pageCount,
                        style: { textAlign: 'center' },
                    }, margin: "dense" }))) : (react_1.default.createElement("div", { className: classes.notFocusedText },
                viewerState.activePage,
                " / ",
                documentData.pageCount)))));
};
exports.DocumentTitlePager = DocumentTitlePager;
//# sourceMappingURL=document-title-pager.js.map