"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.PageList = void 0;
const tslib_1 = require("tslib");
const client_utils_1 = require("@sensenet/client-utils");
const Grid_1 = tslib_1.__importDefault(require("@material-ui/core/Grid"));
const createStyles_1 = tslib_1.__importDefault(require("@material-ui/core/styles/createStyles"));
const makeStyles_1 = tslib_1.__importDefault(require("@material-ui/core/styles/makeStyles"));
const react_1 = tslib_1.__importStar(require("react"));
const hooks_1 = require("../hooks");
const services_1 = require("../services");
const _1 = require("./");
const useStyles = makeStyles_1.default(() => {
    return createStyles_1.default({
        grid: {
            flexGrow: 1,
            flexShrink: 1,
            overflow: 'auto',
        },
        pagesWrapper: {
            display: 'flex',
            flexDirection: 'column',
            justifyContent: 'center',
            alignItems: 'center',
        },
    });
});
const PageList = (props) => {
    const [paddingTop, setPaddingTop] = react_1.useState(0);
    const [paddingBottom, setPaddingBottom] = react_1.useState(0);
    const [visiblePages, setVisiblePages] = react_1.useState([]);
    const [scrollState, setScrollState] = react_1.useState(0);
    const viewportElement = react_1.useRef();
    const viewerState = hooks_1.useViewerState();
    const [resizeToken, setResizeToken] = react_1.useState(0);
    const [viewport, setViewport] = react_1.useState({ width: 0, height: 0 });
    const pages = hooks_1.usePreviewImages();
    const classes = useStyles();
    const requestResize = react_1.useCallback(client_utils_1.debounce(() => {
        setResizeToken(Math.random());
    }, 300), []);
    const onScroll = react_1.useCallback(() => {
        requestResize();
        setScrollState((viewportElement.current && viewportElement.current.scrollTop) || 0);
    }, [requestResize]);
    react_1.useEffect(() => {
        const currentViewport = viewportElement.current;
        if (currentViewport) {
            currentViewport.addEventListener('scroll', onScroll);
        }
        return () => currentViewport && currentViewport.removeEventListener('scroll', onScroll);
    }, [onScroll, viewportElement]);
    react_1.useEffect(() => {
        window.addEventListener('resize', requestResize);
        return () => window.removeEventListener('resize', requestResize);
    }, [requestResize]);
    react_1.useEffect(() => {
        if (viewportElement && viewportElement.current) {
            const newHeight = viewportElement.current.clientHeight - _1.PAGE_PADDING * 2;
            const newWidth = viewportElement.current.clientWidth - _1.PAGE_PADDING * 2;
            setViewport({
                height: newHeight >= 0 ? newHeight : 0,
                width: newWidth >= 0 ? newWidth : 0,
            });
        }
    }, [resizeToken, viewportElement]);
    react_1.useEffect(() => {
        if (!pages.imageData.length) {
            return;
        }
        let defaultWidth;
        let defaultHeight;
        const _visiblePages = pages.imageData.map((p) => {
            var _a, _b;
            if ((p && !defaultWidth) || !defaultHeight) {
                ;
                [defaultWidth, defaultHeight] = [p.Width, p.Height];
            }
            if (!p.Width || !p.Height) {
                ;
                [p.Width, p.Height] = [defaultWidth, defaultHeight];
            }
            const relativeSize = services_1.ImageUtil.getImageSize({
                width: viewport.width,
                height: viewport.height,
            }, {
                width: p.Width,
                height: p.Height,
                rotation: ((_b = (_a = viewerState.rotation) === null || _a === void 0 ? void 0 : _a.find((rotation) => rotation.pageNum === p.Index)) === null || _b === void 0 ? void 0 : _b.degree) || 0,
            }, viewerState.zoomLevel);
            return Object.assign(Object.assign({}, p), { Width: relativeSize.width, Height: relativeSize.height });
        });
        let _paddingTop = 0;
        let _pagesToSkip = 0;
        while (_visiblePages[_pagesToSkip] && _paddingTop + _visiblePages[_pagesToSkip].Height < scrollState) {
            _paddingTop += _visiblePages[_pagesToSkip].Height + _1.PAGE_PADDING * 2;
            _pagesToSkip++;
        }
        let _pagesToTake = 1;
        let _pagesHeight = 0;
        while (_visiblePages[_pagesToSkip + _pagesToTake] && _pagesHeight < viewport.height) {
            _pagesHeight += _visiblePages[_pagesToSkip + _pagesToTake].Height + _1.PAGE_PADDING * 2;
            _pagesToTake++;
        }
        let _paddingBottom = 0;
        for (let i = _pagesToSkip + _pagesToTake - 1; i < _visiblePages.length - 1; i++) {
            _paddingBottom += _visiblePages[i].Height + _1.PAGE_PADDING * 2;
        }
        setPaddingTop(_paddingTop);
        setPaddingBottom(_paddingBottom + _visiblePages[0].Height / 4);
        const newVisiblePages = _visiblePages.slice(_pagesToSkip, _pagesToSkip + _pagesToTake);
        setVisiblePages(newVisiblePages);
        if (newVisiblePages.length > 0) {
            let newActivePage;
            if (newVisiblePages.length === 1) {
                newActivePage = newVisiblePages[0].Index;
            }
            else {
                newActivePage =
                    scrollState - _paddingTop >= 0 && scrollState - _paddingTop > newVisiblePages[0].Height / 2
                        ? newVisiblePages[1].Index
                        : newVisiblePages[0].Index;
            }
            if (viewerState.activePage !== newActivePage) {
                viewerState.updateState({ activePage: newActivePage });
            }
        }
    }, [pages.imageData, scrollState, viewerState, viewport.height, viewport.width]);
    return (react_1.default.createElement(Grid_1.default, { item: true, className: classes.grid, id: _1.PAGE_CONTAINER_ID, innerRef: viewportElement },
        react_1.default.createElement("div", { className: classes.pagesWrapper, style: { paddingTop: paddingTop || 0, paddingBottom: paddingBottom || 0 } }, visiblePages.map((page) => (react_1.default.createElement(_1.Page, { key: page.Index, page: page, viewportWidth: viewport.width, viewportHeight: viewport.height, onClick: () => props.onPageClick(page.Index) }))))));
};
exports.PageList = PageList;
//# sourceMappingURL=page-list.js.map