"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.Page = exports.ANNOTATION_EXTRA_VALUES = void 0;
const tslib_1 = require("tslib");
const CircularProgress_1 = tslib_1.__importDefault(require("@material-ui/core/CircularProgress"));
const Paper_1 = tslib_1.__importDefault(require("@material-ui/core/Paper"));
const createStyles_1 = tslib_1.__importDefault(require("@material-ui/core/styles/createStyles"));
const makeStyles_1 = tslib_1.__importDefault(require("@material-ui/core/styles/makeStyles"));
const clsx_1 = tslib_1.__importDefault(require("clsx"));
const react_1 = tslib_1.__importStar(require("react"));
const hooks_1 = require("../hooks");
const services_1 = require("../services");
const document_viewer_layout_1 = require("./document-viewer-layout");
const shapes_1 = require("./shapes");
exports.ANNOTATION_EXTRA_VALUES = {
    text: '',
    lineHeight: 40,
    fontBold: 400,
    fontColor: '#000000',
    fontFamily: 'arial',
    fontItalic: false,
    fontSize: 40,
};
const useStyles = makeStyles_1.default(() => {
    return createStyles_1.default({
        page: {
            padding: 0,
            overflow: 'hidden',
            width: ({ page }) => page.Width,
            height: ({ page }) => page.Height,
            position: 'relative',
        },
        image: {
            display: 'flex',
            justifyContent: 'center',
        },
        isPlacingShape: {
            cursor: 'crosshair',
        },
        draftShapeContainer: {
            position: 'absolute',
            top: 0,
            left: 0,
            width: '100%',
            height: '100%',
            zIndex: 1,
        },
    });
});
const Page = (props) => {
    var _a, _b, _c, _d, _e, _f, _g;
    const classes = useStyles(props);
    const viewerState = hooks_1.useViewerState();
    const page = hooks_1.usePreviewImage(props.page.Index);
    const commentState = hooks_1.useCommentState();
    const [mouseIsDown, setMouseIsDown] = react_1.useState(false);
    const [startX, setStartX] = react_1.useState(0);
    const [startY, setStartY] = react_1.useState(0);
    const [draftWidth, setdraftWidth] = react_1.useState(0);
    const [draftHeight, setdraftHeight] = react_1.useState(0);
    const { documentData, updateDocumentData } = hooks_1.useDocumentData();
    const isActive = page.image && viewerState.activePage === page.image.Index;
    const imgUrl = (page.image && ((_a = page.image) === null || _a === void 0 ? void 0 : _a.PreviewImageUrl)) || '';
    const imageRotation = services_1.ImageUtil.normalizeDegrees(((_c = (_b = viewerState.rotation) === null || _b === void 0 ? void 0 : _b.find((rotation) => rotation.pageNum === props.page.Index)) === null || _c === void 0 ? void 0 : _c.degree) || 0);
    const imageRotationRads = ((imageRotation % 180) * Math.PI) / 180;
    const boundingBox = services_1.ImageUtil.getRotatedBoundingBoxSize({
        width: ((_d = page.image) === null || _d === void 0 ? void 0 : _d.Width) || 0,
        height: ((_e = page.image) === null || _e === void 0 ? void 0 : _e.Height) || 0,
    }, imageRotation);
    const diffHeight = Math.sin(imageRotationRads) * ((props.page.Height - props.page.Width) / 2);
    const imageTransform = `translateY(${diffHeight}px) rotate(${imageRotation}deg)`;
    const handleMarkerPlacement = react_1.useCallback((event) => {
        var _a, _b;
        if (imageRotation !== 0) {
            viewerState.updateState({ isPlacingCommentMarker: false });
        }
        const xCoord = event.nativeEvent.offsetX / (props.page.Height / (((_a = page.image) === null || _a === void 0 ? void 0 : _a.Height) || 1));
        const yCoord = event.nativeEvent.offsetY / (props.page.Width / (((_b = page.image) === null || _b === void 0 ? void 0 : _b.Width) || 1));
        if (!viewerState.isPlacingCommentMarker || xCoord <= shapes_1.MARKER_SIZE || yCoord <= shapes_1.MARKER_SIZE) {
            return;
        }
        const newCommentMarker = {
            x: `${xCoord - shapes_1.MARKER_SIZE}`,
            y: `${yCoord - shapes_1.MARKER_SIZE}`,
            id: 'draft',
            page: viewerState.activePage,
        };
        commentState.setDraft(newCommentMarker);
    }, [
        commentState,
        imageRotation,
        (_f = page.image) === null || _f === void 0 ? void 0 : _f.Height,
        (_g = page.image) === null || _g === void 0 ? void 0 : _g.Width,
        props.page.Height,
        props.page.Width,
        viewerState,
    ]);
    const handleMouseDown = (ev) => {
        var _a, _b;
        if (imageRotation !== 0) {
            viewerState.updateState({ activeShapePlacing: 'none' });
        }
        setMouseIsDown(true);
        setStartX(ev.nativeEvent.offsetX / (props.page.Height / (((_a = page.image) === null || _a === void 0 ? void 0 : _a.Height) || 1)));
        setStartY(ev.nativeEvent.offsetY / (props.page.Width / (((_b = page.image) === null || _b === void 0 ? void 0 : _b.Width) || 1)));
    };
    const handleMouseMove = (ev) => {
        var _a, _b;
        const endX = ev.nativeEvent.offsetX / (props.page.Height / (((_a = page.image) === null || _a === void 0 ? void 0 : _a.Height) || 1));
        const endY = ev.nativeEvent.offsetY / (props.page.Width / (((_b = page.image) === null || _b === void 0 ? void 0 : _b.Width) || 1));
        setdraftHeight(endY - startY);
        setdraftWidth(endX - startX);
    };
    const handleMouseUp = (ev, shapeType) => {
        var _a, _b;
        setMouseIsDown(false);
        setdraftHeight(0);
        setdraftWidth(0);
        const endX = ev.nativeEvent.offsetX / (props.page.Height / (((_a = page.image) === null || _a === void 0 ? void 0 : _a.Height) || 1));
        const endY = ev.nativeEvent.offsetY / (props.page.Width / (((_b = page.image) === null || _b === void 0 ? void 0 : _b.Width) || 1));
        if (endY - startY > 0 && endX - startX > 0) {
            switch (shapeType) {
                case 'annotation':
                    documentData.shapes.annotations.push(Object.assign({ h: endY - startY, w: endX - startX, x: startX, y: startY, imageIndex: props.page.Index, guid: `a-${startX}-${startY}` }, exports.ANNOTATION_EXTRA_VALUES));
                    updateDocumentData(documentData);
                    viewerState.updateState({
                        hasChanges: true,
                        activeShapePlacing: 'none',
                        showShapes: true,
                    });
                    break;
                case 'highlight':
                    documentData.shapes.highlights.push({
                        h: endY - startY,
                        w: endX - startX,
                        x: startX,
                        y: startY,
                        imageIndex: props.page.Index,
                        guid: `h-${startX}-${startY}`,
                    });
                    updateDocumentData(documentData);
                    viewerState.updateState({
                        hasChanges: true,
                        activeShapePlacing: 'none',
                        showShapes: true,
                    });
                    break;
                case 'redaction':
                    documentData.shapes.redactions.push({
                        h: endY - startY,
                        w: endX - startX,
                        x: startX,
                        y: startY,
                        imageIndex: props.page.Index,
                        guid: `r-${startX}-${startY}`,
                    });
                    updateDocumentData(documentData);
                    viewerState.updateState({
                        hasChanges: true,
                        activeShapePlacing: 'none',
                        showRedaction: true,
                    });
                    break;
                default:
                    break;
            }
        }
        setStartX(0);
        setStartY(0);
    };
    return (react_1.default.createElement(Paper_1.default, { elevation: isActive ? 8 : 2, className: document_viewer_layout_1.PAGE_NAME, style: { margin: document_viewer_layout_1.PAGE_PADDING } },
        react_1.default.createElement("div", { className: clsx_1.default(classes.page, {
                [classes.isPlacingShape]: viewerState.activeShapePlacing !== 'none',
            }), onClick: (ev) => {
                viewerState.isPlacingCommentMarker ? handleMarkerPlacement(ev) : props.onClick(ev);
            }, onMouseDown: (ev) => {
                viewerState.activeShapePlacing !== 'none' && !mouseIsDown && handleMouseDown(ev);
            }, onMouseMove: (ev) => {
                viewerState.activeShapePlacing !== 'none' && mouseIsDown && handleMouseMove(ev);
            }, onMouseUp: (ev) => {
                mouseIsDown && handleMouseUp(ev, viewerState.activeShapePlacing);
            } },
            page.image && (react_1.default.createElement(react_1.default.Fragment, null,
                react_1.default.createElement(shapes_1.ShapesWidget, { imageRotation: imageRotation, zoomRatioStanding: props.page.Height / page.image.Height, zoomRatioLying: props.page.Width / page.image.Height, page: page.image }),
                mouseIsDown && (react_1.default.createElement("div", { className: classes.draftShapeContainer },
                    react_1.default.createElement(shapes_1.ShapeDraft, { dimensions: {
                            top: startY * (props.page.Height / page.image.Height),
                            left: startX * (props.page.Height / page.image.Height),
                            height: draftHeight * (props.page.Height / page.image.Height),
                            width: draftWidth * (props.page.Height / page.image.Height),
                        } }))))),
            react_1.default.createElement("span", { className: classes.image }, imgUrl ? (react_1.default.createElement("img", { src: `${imgUrl}${viewerState.showWatermark ? '?watermark=true' : ''}`, alt: "", style: {
                    transition: 'transform .1s ease-in-out',
                    width: `${100 * boundingBox.zoomRatio}%`,
                    height: `${100 * boundingBox.zoomRatio}%`,
                    transform: imageTransform,
                } })) : (react_1.default.createElement(CircularProgress_1.default, { style: { marginTop: '50%' } }))))));
};
exports.Page = Page;
//# sourceMappingURL=page.js.map