"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.CommentMarker = exports.MARKER_SIZE = void 0;
const tslib_1 = require("tslib");
const createStyles_1 = tslib_1.__importDefault(require("@material-ui/core/styles/createStyles"));
const makeStyles_1 = tslib_1.__importDefault(require("@material-ui/core/styles/makeStyles"));
const react_1 = tslib_1.__importDefault(require("react"));
const __1 = require("../..");
exports.MARKER_SIZE = 10;
const useStyles = makeStyles_1.default((theme) => createStyles_1.default({
    root: {
        position: 'absolute',
        top: ({ rotation, marker, zoomRatio }) => {
            switch (rotation) {
                case 90:
                    return `${parseFloat(marker.x) * zoomRatio}px`;
                case 180:
                    return 'unset';
                case 270:
                    return 'unset';
                default:
                    return `${parseFloat(marker.y) * zoomRatio}px`;
            }
        },
        right: ({ rotation, marker, zoomRatio }) => {
            switch (rotation) {
                case 90:
                    return `${parseFloat(marker.y) * zoomRatio}px`;
                case 180:
                    return `${parseFloat(marker.x) * zoomRatio}px`;
                case 270:
                    return 'unset';
                default:
                    return 'unset';
            }
        },
        bottom: ({ rotation, marker, zoomRatio }) => {
            switch (rotation) {
                case 90:
                    return 'unset';
                case 180:
                    return `${parseFloat(marker.y) * zoomRatio}px`;
                case 270:
                    return `${parseFloat(marker.x) * zoomRatio}px`;
                default:
                    return 'unset';
            }
        },
        left: ({ rotation, marker, zoomRatio }) => {
            switch (rotation) {
                case 90:
                    return 'unset';
                case 180:
                    return 'unset';
                case 270:
                    return `${parseFloat(marker.y) * zoomRatio}px`;
                default:
                    return `${parseFloat(marker.x) * zoomRatio}px`;
            }
        },
        width: `${exports.MARKER_SIZE}px`,
        height: `${exports.MARKER_SIZE}px`,
        borderRadius: `${exports.MARKER_SIZE}px`,
        backgroundColor: ({ isSelected }) => (isSelected ? theme.palette.primary.light : theme.palette.primary.dark),
        cursor: 'pointer',
    },
}));
/**
 * Return a styled comment marker component
 * @param marker Attributes of the marker
 * @param zoomRatio Zoom ratio
 * @param isSelected Flag to store is marker is selected or not
 * @param rotation Page rotation degree
 * @returns styled comment marker component
 */
function CommentMarker({ marker, zoomRatio, isSelected, rotation }) {
    const classes = useStyles({ marker, zoomRatio, isSelected, rotation });
    const viewerState = __1.useViewerState();
    const commentState = __1.useCommentState();
    return (react_1.default.createElement("div", { className: classes.root, onClick: (ev) => {
            ev.stopPropagation();
            ev.nativeEvent.stopImmediatePropagation();
            !viewerState.isPlacingCommentMarker && commentState.setActiveComment(marker.id);
        } }));
}
exports.CommentMarker = CommentMarker;
//# sourceMappingURL=comment-marker.js.map