"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.ShapeHighlight = void 0;
const tslib_1 = require("tslib");
const Button_1 = tslib_1.__importDefault(require("@material-ui/core/Button/Button"));
const ClickAwayListener_1 = tslib_1.__importDefault(require("@material-ui/core/ClickAwayListener/ClickAwayListener"));
const yellow_1 = tslib_1.__importDefault(require("@material-ui/core/colors/yellow"));
const Popper_1 = tslib_1.__importDefault(require("@material-ui/core/Popper/Popper"));
const createStyles_1 = tslib_1.__importDefault(require("@material-ui/core/styles/createStyles"));
const makeStyles_1 = tslib_1.__importDefault(require("@material-ui/core/styles/makeStyles"));
const Delete_1 = tslib_1.__importDefault(require("@material-ui/icons/Delete"));
const react_1 = tslib_1.__importStar(require("react"));
const __1 = require("../..");
const hooks_1 = require("../../hooks");
const useStyles = makeStyles_1.default((theme) => createStyles_1.default({
    root: {
        top: ({ dimensions }) => dimensions.top,
        left: ({ dimensions }) => dimensions.left,
        width: ({ dimensions }) => dimensions.width,
        height: ({ dimensions }) => dimensions.height,
        position: 'absolute',
        resize: ({ permissions, rotationDegree }) => (permissions.canEdit && rotationDegree === 0 ? 'both' : 'none'),
        overflow: 'auto',
        backgroundColor: yellow_1.default[600],
        opacity: 0.5,
    },
    button: {
        backgroundColor: theme.palette.error.light,
    },
}));
/**
 * Return a styled highlight component
 * @param shape Shape attributes
 * @param permissions Permissions of the current user
 * @param dimensions Shape dimensions
 * @param zoomRatio Zoom ratio
 * @param onDragStart Function triggered on drag event
 * @param onResized Function triggered on resized event
 * @param removeShape Function triggered on delete
 * @returns styled highlight component
 */
const ShapeHighlight = (props) => {
    const permissions = hooks_1.useDocumentPermissions();
    const classes = useStyles(Object.assign(Object.assign({}, props), { permissions }));
    const localization = __1.useLocalization();
    const [anchorEl, setAnchorEl] = react_1.useState(null);
    const open = Boolean(anchorEl);
    const id = open ? 'highlight-delete' : undefined;
    const onRightClick = (event) => {
        event.preventDefault();
        setAnchorEl(anchorEl ? null : event.currentTarget);
    };
    return (react_1.default.createElement(react_1.default.Fragment, null,
        react_1.default.createElement("div", { className: classes.root, tabIndex: 0, draggable: permissions.canEdit, onDragStart: props.onDragStart, onMouseUp: props.onResized, onContextMenu: onRightClick }),
        react_1.default.createElement(Popper_1.default, { id: id, open: open, anchorEl: anchorEl, placement: "right-start" },
            react_1.default.createElement(ClickAwayListener_1.default, { onClickAway: () => setAnchorEl(null) },
                react_1.default.createElement(Button_1.default, { variant: "contained", className: classes.button, onMouseUp: () => props.removeShape('highlights', props.shape.guid), startIcon: react_1.default.createElement(Delete_1.default, { scale: props.zoomRatio }) }, localization.delete)))));
};
exports.ShapeHighlight = ShapeHighlight;
//# sourceMappingURL=shape-highlight.js.map