"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.ShapesWidget = void 0;
const tslib_1 = require("tslib");
const createStyles_1 = tslib_1.__importDefault(require("@material-ui/core/styles/createStyles"));
const makeStyles_1 = tslib_1.__importDefault(require("@material-ui/core/styles/makeStyles"));
const react_1 = tslib_1.__importStar(require("react"));
const hooks_1 = require("../../hooks");
const services_1 = require("../../services");
const shapes_1 = require("../shapes");
const comment_marker_1 = require("./comment-marker");
const useStyles = makeStyles_1.default(() => {
    return createStyles_1.default({
        shapesContainer: {
            position: 'absolute',
            top: 0,
            left: 0,
            width: '100%',
            height: '100%',
            zIndex: 1,
        },
    });
});
/**
 * Page widget component for displaying shapes on a page
 */
const ShapesWidget = (props) => {
    var _a, _b, _c, _d;
    const classes = useStyles();
    const permissions = hooks_1.useDocumentPermissions();
    const viewerState = hooks_1.useViewerState();
    const { documentData, updateDocumentData } = hooks_1.useDocumentData();
    const comments = hooks_1.useComments();
    const commentState = hooks_1.useCommentState();
    const zoomRatio = props.imageRotation === 90 || props.imageRotation === 270 ? props.zoomRatioLying : props.zoomRatioStanding;
    const rotationDegree = ((_b = (_a = viewerState.rotation) === null || _a === void 0 ? void 0 : _a.find((rotation) => rotation.pageNum === props.page.Index)) === null || _b === void 0 ? void 0 : _b.degree) || 0;
    const visibleShapes = {
        redactions: services_1.applyShapeRotations(documentData.shapes.redactions.filter((r) => r.imageIndex === props.page.Index), rotationDegree, props.page),
        highlights: services_1.applyShapeRotations(documentData.shapes.highlights.filter((r) => r.imageIndex === props.page.Index), rotationDegree, props.page),
        annotations: services_1.applyShapeRotations(documentData.shapes.annotations.filter((r) => r.imageIndex === props.page.Index), rotationDegree, props.page),
    };
    const visibleComments = [
        ...comments.comments.filter((comment) => comment.page === props.page.Index),
        ...(props.page.Index !== undefined && ((_c = commentState.draft) === null || _c === void 0 ? void 0 : _c.page) === ((_d = props.page) === null || _d === void 0 ? void 0 : _d.Index) ? [commentState.draft] : []),
    ];
    const removeShape = react_1.useCallback((shapeType, guid) => {
        ;
        documentData.shapes[shapeType] = documentData.shapes[shapeType].filter((s) => s.guid !== guid);
        updateDocumentData(documentData);
        viewerState.updateState({ hasChanges: true });
    }, [documentData, updateDocumentData, viewerState]);
    const updateShapeData = react_1.useCallback((shapeType, guid, shapeChange) => {
        ;
        documentData.shapes[shapeType] = documentData.shapes[shapeType].map((s) => {
            if (s.guid === guid) {
                return Object.assign(Object.assign({}, s), shapeChange);
            }
            return s;
        });
        viewerState.updateState({ hasChanges: true });
        updateDocumentData(documentData);
    }, [documentData, updateDocumentData, viewerState]);
    const onDrop = react_1.useCallback((ev) => {
        if (permissions.canEdit) {
            ev.preventDefault();
            const shapeData = JSON.parse(ev.dataTransfer.getData('shape'));
            const boundingBox = ev.currentTarget.getBoundingClientRect();
            updateShapeData(shapeData.type, shapeData.shape.guid, Object.assign(Object.assign({}, shapeData.shape), { imageIndex: props.page.Index, x: (ev.clientX - boundingBox.left - shapeData.offset.width) * (1 / zoomRatio), y: (ev.clientY - boundingBox.top - shapeData.offset.height) * (1 / zoomRatio) }));
        }
    }, [permissions.canEdit, props.page.Index, updateShapeData, zoomRatio]);
    return (react_1.default.createElement("div", { className: classes.shapesContainer, onDrop: onDrop, onDragOver: (ev) => ev.preventDefault() },
        viewerState.showComments &&
            visibleComments.length > 0 &&
            visibleComments.map((marker) => {
                var _a, _b;
                return (react_1.default.createElement(comment_marker_1.CommentMarker, { isSelected: marker.id === commentState.activeCommentId, zoomRatio: zoomRatio, marker: marker, key: marker.id, rotation: services_1.ImageUtil.normalizeDegrees(((_b = (_a = viewerState.rotation) === null || _a === void 0 ? void 0 : _a.find((rotation) => rotation.pageNum === props.page.Index)) === null || _b === void 0 ? void 0 : _b.degree) || 0) }));
            }),
        react_1.default.createElement(react_1.default.Fragment, null,
            permissions.canHideRedaction &&
                viewerState.showRedaction &&
                visibleShapes.redactions.map((redaction, index) => {
                    return (react_1.default.createElement(shapes_1.ShapeSkeleton, { key: index, shape: redaction, shapeType: "redactions", zoomRatio: zoomRatio, updateShapeData: updateShapeData, removeShape: removeShape, rotationDegree: rotationDegree }));
                }),
            viewerState.showShapes &&
                visibleShapes.annotations.map((annotation, index) => {
                    return (react_1.default.createElement(shapes_1.ShapeSkeleton, { key: index, shape: annotation, shapeType: "annotations", zoomRatio: zoomRatio, updateShapeData: updateShapeData, removeShape: removeShape, rotationDegree: rotationDegree }));
                }),
            viewerState.showShapes &&
                visibleShapes.highlights.map((highlight, index) => {
                    return (react_1.default.createElement(shapes_1.ShapeSkeleton, { key: index, shape: highlight, shapeType: "highlights", zoomRatio: zoomRatio, updateShapeData: updateShapeData, removeShape: removeShape, rotationDegree: rotationDegree }));
                }))));
};
exports.ShapesWidget = ShapesWidget;
//# sourceMappingURL=shapes.js.map