"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.Thumbnails = void 0;
const tslib_1 = require("tslib");
const Grid_1 = tslib_1.__importDefault(require("@material-ui/core/Grid"));
const createStyles_1 = tslib_1.__importDefault(require("@material-ui/core/styles/createStyles"));
const makeStyles_1 = tslib_1.__importDefault(require("@material-ui/core/styles/makeStyles"));
const react_1 = tslib_1.__importStar(require("react"));
const __1 = require("..");
const hooks_1 = require("../hooks");
const services_1 = require("../services");
const _1 = require("./");
const useStyles = makeStyles_1.default(() => {
    return createStyles_1.default({
        grid: {
            flexGrow: 1,
            flexShrink: 1,
            overflow: 'auto',
        },
        thumbnailsWrapper: {
            display: 'flex',
            flexDirection: 'column',
            justifyContent: 'center',
            alignItems: 'center',
        },
    });
});
const Thumbnails = (props) => {
    const classes = useStyles();
    const [marginTop, setMarginTop] = react_1.useState(0);
    const [marginBottom, setMarginBottom] = react_1.useState(0);
    const [visiblePages, setVisiblePages] = react_1.useState([]);
    const [scrollState, setScrollState] = react_1.useState(0);
    const viewportElement = react_1.useRef();
    const viewerState = hooks_1.useViewerState();
    const [resizeToken, setResizeToken] = react_1.useState(0);
    const [viewport, setViewport] = react_1.useState({ width: 0, height: 0 });
    const pages = hooks_1.usePreviewImages();
    const requestResize = react_1.useCallback(() => {
        setResizeToken(Math.random());
    }, []);
    const onScroll = react_1.useCallback(() => {
        requestResize();
        setScrollState((viewportElement.current && viewportElement.current.scrollTop) || 0);
    }, [requestResize]);
    react_1.useEffect(() => {
        const currentViewport = viewportElement.current;
        if (currentViewport) {
            currentViewport.addEventListener('scroll', onScroll);
        }
        return () => currentViewport && currentViewport.removeEventListener('scroll', onScroll);
    }, [onScroll, viewportElement]);
    react_1.useEffect(() => {
        window.addEventListener('resize', requestResize);
        return () => window.removeEventListener('resize', requestResize);
    }, [requestResize]);
    react_1.useEffect(() => {
        if (viewportElement && viewportElement.current) {
            const newHeight = viewportElement.current.clientHeight - _1.THUMBNAIL_PADDING * 2;
            const newWidth = viewportElement.current.clientWidth - _1.THUMBNAIL_PADDING * 2;
            setViewport({
                height: newHeight >= 0 ? newHeight : 0,
                width: newWidth >= 0 ? newWidth : 0,
            });
        }
    }, [resizeToken, viewportElement]);
    react_1.useEffect(() => {
        if (!pages.imageData.length) {
            return;
        }
        let defaultWidth;
        let defaultHeight;
        const _visiblePages = pages.imageData.map((p) => {
            var _a, _b;
            if ((p && !defaultWidth) || !defaultHeight) {
                ;
                [defaultWidth, defaultHeight] = [p.Width, p.Height];
            }
            if (!p.Width || !p.Height) {
                ;
                [p.Width, p.Height] = [defaultWidth, defaultHeight];
            }
            const relativeSize = services_1.ImageUtil.getImageSize({
                width: viewport.width,
                height: viewport.height,
            }, {
                width: p.Width,
                height: p.Height,
                rotation: ((_b = (_a = viewerState.rotation) === null || _a === void 0 ? void 0 : _a.find((rotation) => rotation.pageNum === p.Index)) === null || _b === void 0 ? void 0 : _b.degree) || 0,
            }, __1.DEFAULT_ZOOM_LEVEL);
            return Object.assign(Object.assign({}, p), { Width: relativeSize.width, Height: relativeSize.height });
        });
        let _marginTop = 0;
        let _pagesToSkip = 0;
        while (_visiblePages[_pagesToSkip] && _marginTop + _visiblePages[_pagesToSkip].Height < scrollState) {
            _marginTop += _visiblePages[_pagesToSkip].Height + _1.THUMBNAIL_PADDING * 2;
            _pagesToSkip++;
        }
        let _pagesToTake = 1;
        let _pagesHeight = 0;
        while (_visiblePages[_pagesToSkip + _pagesToTake] && _pagesHeight < viewport.height) {
            _pagesHeight += _visiblePages[_pagesToSkip + _pagesToTake].Height + _1.THUMBNAIL_PADDING * 2;
            _pagesToTake++;
        }
        let _marginBottom = 0;
        for (let i = _pagesToSkip + _pagesToTake - 1; i < _visiblePages.length - 1; i++) {
            _marginBottom += _visiblePages[i].Height + _1.THUMBNAIL_PADDING * 2;
        }
        setMarginTop(_marginTop);
        setMarginBottom(_marginBottom);
        const newVisiblePages = _visiblePages.slice(_pagesToSkip, _pagesToSkip + _pagesToTake);
        setVisiblePages(newVisiblePages);
    }, [pages.imageData, scrollState, viewerState, viewport.height, viewport.width]);
    return (react_1.default.createElement(Grid_1.default, { item: true, className: classes.grid, id: _1.THUMBNAIL_CONTAINER_ID, innerRef: viewportElement },
        react_1.default.createElement("div", { className: classes.thumbnailsWrapper, style: {
                paddingTop: marginTop || 0,
                paddingBottom: marginBottom || 0,
            } }, visiblePages.map((page) => (react_1.default.createElement(_1.ThumbnailPage, { key: page.Index, page: page, viewportWidth: viewport.width, viewportHeight: viewport.height, onClick: () => props.onPageClick(page.Index) }))))));
};
exports.Thumbnails = Thumbnails;
//# sourceMappingURL=thumbnails.js.map