"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.PreviewImageDataContextProvider = exports.PreviewImageDataContext = void 0;
const tslib_1 = require("tslib");
const react_1 = tslib_1.__importStar(require("react"));
const __1 = require("..");
const hooks_1 = require("../hooks");
exports.PreviewImageDataContext = react_1.default.createContext({ imageData: [], setImageData: () => ({}) });
const PreviewImageDataContextProvider = (props) => {
    const viewerSettings = hooks_1.useViewerSettings();
    const api = hooks_1.useDocumentViewerApi();
    const { documentData } = hooks_1.useDocumentData();
    const viewerState = hooks_1.useViewerState();
    const [previewImages, setPreviewImages] = react_1.useState([]);
    react_1.useEffect(() => {
        if (documentData.pageCount <= __1.PreviewState.Empty) {
            return;
        }
        const abortController = new AbortController();
        (() => tslib_1.__awaiter(void 0, void 0, void 0, function* () {
            try {
                setPreviewImages([]);
                const images = yield api.getExistingPreviewImages({
                    document: documentData,
                    version: viewerSettings.version || '',
                    showWatermark: viewerState.showWatermark,
                    abortController,
                });
                setPreviewImages(images);
            }
            catch (error) {
                if (!abortController.signal.aborted) {
                    throw error;
                }
            }
        }))();
        return () => abortController.abort();
    }, [api, documentData, viewerSettings.version, viewerState.showWatermark]);
    return (react_1.default.createElement(exports.PreviewImageDataContext.Provider, { value: {
            imageData: previewImages,
            setImageData: setPreviewImages,
        } }, props.children));
};
exports.PreviewImageDataContextProvider = PreviewImageDataContextProvider;
//# sourceMappingURL=preview-image-data.js.map