import { CircularProgress, createStyles, makeStyles, Paper } from '@material-ui/core';
import clsx from 'clsx';
import React, { useCallback, useState } from 'react';
import { useCommentState, useDocumentData, usePreviewImage, useViewerState } from "../hooks/index.js";
import { ImageUtil } from "../services/index.js";
import { PAGE_NAME, PAGE_PADDING } from "./document-viewer-layout.js";
import { MARKER_SIZE, ShapeDraft, ShapesWidget } from "./shapes/index.js";
export const ANNOTATION_EXTRA_VALUES = {
  text: '',
  lineHeight: 40,
  fontBold: 400,
  fontColor: '#000000',
  fontFamily: 'arial',
  fontItalic: false,
  fontSize: 40
};
const useStyles = makeStyles(() => {
  return createStyles({
    page: {
      padding: 0,
      overflow: 'hidden',
      width: ({
        page
      }) => page.Width,
      height: ({
        page
      }) => page.Height,
      position: 'relative'
    },
    image: {
      display: 'flex',
      justifyContent: 'center'
    },
    isPlacingShape: {
      cursor: 'crosshair'
    },
    draftShapeContainer: {
      position: 'absolute',
      top: 0,
      left: 0,
      width: '100%',
      height: '100%',
      zIndex: 1
    }
  });
});
/**
 * Defined the component's own properties
 */

export const Page = props => {
  var _page$image, _viewerState$rotation, _viewerState$rotation2, _page$image2, _page$image3, _page$image6, _page$image7;

  const classes = useStyles(props);
  const viewerState = useViewerState();
  const page = usePreviewImage(props.page.Index);
  const commentState = useCommentState();
  const [mouseIsDown, setMouseIsDown] = useState(false);
  const [startX, setStartX] = useState(0);
  const [startY, setStartY] = useState(0);
  const [draftWidth, setdraftWidth] = useState(0);
  const [draftHeight, setdraftHeight] = useState(0);
  const {
    documentData,
    updateDocumentData
  } = useDocumentData();
  const isActive = page.image && viewerState.activePage === page.image.Index;
  const imgUrl = page.image && ((_page$image = page.image) === null || _page$image === void 0 ? void 0 : _page$image.PreviewImageUrl) || '';
  const imageRotation = ImageUtil.normalizeDegrees(((_viewerState$rotation = viewerState.rotation) === null || _viewerState$rotation === void 0 ? void 0 : (_viewerState$rotation2 = _viewerState$rotation.find(rotation => rotation.pageNum === props.page.Index)) === null || _viewerState$rotation2 === void 0 ? void 0 : _viewerState$rotation2.degree) || 0);
  const imageRotationRads = imageRotation % 180 * Math.PI / 180;
  const boundingBox = ImageUtil.getRotatedBoundingBoxSize({
    width: ((_page$image2 = page.image) === null || _page$image2 === void 0 ? void 0 : _page$image2.Width) || 0,
    height: ((_page$image3 = page.image) === null || _page$image3 === void 0 ? void 0 : _page$image3.Height) || 0
  }, imageRotation);
  const diffHeight = Math.sin(imageRotationRads) * ((props.page.Height - props.page.Width) / 2);
  const imageTransform = `translateY(${diffHeight}px) rotate(${imageRotation}deg)`;
  const handleMarkerPlacement = useCallback(event => {
    var _page$image4, _page$image5;

    if (imageRotation !== 0) {
      viewerState.updateState({
        isPlacingCommentMarker: false
      });
    }

    const xCoord = event.nativeEvent.offsetX / (props.page.Height / (((_page$image4 = page.image) === null || _page$image4 === void 0 ? void 0 : _page$image4.Height) || 1));
    const yCoord = event.nativeEvent.offsetY / (props.page.Width / (((_page$image5 = page.image) === null || _page$image5 === void 0 ? void 0 : _page$image5.Width) || 1));

    if (!viewerState.isPlacingCommentMarker || xCoord <= MARKER_SIZE || yCoord <= MARKER_SIZE) {
      return;
    }

    const newCommentMarker = {
      x: `${xCoord - MARKER_SIZE}`,
      y: `${yCoord - MARKER_SIZE}`,
      id: 'draft',
      page: viewerState.activePage
    };
    commentState.setDraft(newCommentMarker);
  }, [commentState, imageRotation, (_page$image6 = page.image) === null || _page$image6 === void 0 ? void 0 : _page$image6.Height, (_page$image7 = page.image) === null || _page$image7 === void 0 ? void 0 : _page$image7.Width, props.page.Height, props.page.Width, viewerState]);

  const handleMouseDown = ev => {
    var _page$image8, _page$image9;

    if (imageRotation !== 0) {
      viewerState.updateState({
        activeShapePlacing: 'none'
      });
    }

    setMouseIsDown(true);
    setStartX(ev.nativeEvent.offsetX / (props.page.Height / (((_page$image8 = page.image) === null || _page$image8 === void 0 ? void 0 : _page$image8.Height) || 1)));
    setStartY(ev.nativeEvent.offsetY / (props.page.Width / (((_page$image9 = page.image) === null || _page$image9 === void 0 ? void 0 : _page$image9.Width) || 1)));
  };

  const handleMouseMove = ev => {
    var _page$image10, _page$image11;

    const endX = ev.nativeEvent.offsetX / (props.page.Height / (((_page$image10 = page.image) === null || _page$image10 === void 0 ? void 0 : _page$image10.Height) || 1));
    const endY = ev.nativeEvent.offsetY / (props.page.Width / (((_page$image11 = page.image) === null || _page$image11 === void 0 ? void 0 : _page$image11.Width) || 1));
    setdraftHeight(endY - startY);
    setdraftWidth(endX - startX);
  };

  const handleMouseUp = (ev, shapeType) => {
    var _page$image12, _page$image13;

    setMouseIsDown(false);
    setdraftHeight(0);
    setdraftWidth(0);
    const endX = ev.nativeEvent.offsetX / (props.page.Height / (((_page$image12 = page.image) === null || _page$image12 === void 0 ? void 0 : _page$image12.Height) || 1));
    const endY = ev.nativeEvent.offsetY / (props.page.Width / (((_page$image13 = page.image) === null || _page$image13 === void 0 ? void 0 : _page$image13.Width) || 1));

    if (endY - startY > 0 && endX - startX > 0) {
      switch (shapeType) {
        case 'annotation':
          documentData.shapes.annotations.push({
            h: endY - startY,
            w: endX - startX,
            x: startX,
            y: startY,
            imageIndex: props.page.Index,
            guid: `a-${startX}-${startY}`,
            ...ANNOTATION_EXTRA_VALUES
          });
          updateDocumentData(documentData);
          viewerState.updateState({
            hasChanges: true,
            activeShapePlacing: 'none',
            showShapes: true
          });
          break;

        case 'highlight':
          documentData.shapes.highlights.push({
            h: endY - startY,
            w: endX - startX,
            x: startX,
            y: startY,
            imageIndex: props.page.Index,
            guid: `h-${startX}-${startY}`
          });
          updateDocumentData(documentData);
          viewerState.updateState({
            hasChanges: true,
            activeShapePlacing: 'none',
            showShapes: true
          });
          break;

        case 'redaction':
          documentData.shapes.redactions.push({
            h: endY - startY,
            w: endX - startX,
            x: startX,
            y: startY,
            imageIndex: props.page.Index,
            guid: `r-${startX}-${startY}`
          });
          updateDocumentData(documentData);
          viewerState.updateState({
            hasChanges: true,
            activeShapePlacing: 'none',
            showRedaction: true
          });
          break;

        default:
          break;
      }
    }

    setStartX(0);
    setStartY(0);
  };

  return /*#__PURE__*/React.createElement(Paper, {
    elevation: isActive ? 8 : 2,
    className: PAGE_NAME,
    style: {
      margin: PAGE_PADDING
    }
  }, /*#__PURE__*/React.createElement("div", {
    className: clsx(classes.page, {
      [classes.isPlacingShape]: viewerState.activeShapePlacing !== 'none'
    }),
    onClick: ev => {
      viewerState.isPlacingCommentMarker ? handleMarkerPlacement(ev) : props.onClick(ev);
    },
    onMouseDown: ev => {
      viewerState.activeShapePlacing !== 'none' && !mouseIsDown && handleMouseDown(ev);
    },
    onMouseMove: ev => {
      viewerState.activeShapePlacing !== 'none' && mouseIsDown && handleMouseMove(ev);
    },
    onMouseUp: ev => {
      mouseIsDown && handleMouseUp(ev, viewerState.activeShapePlacing);
    }
  }, page.image && /*#__PURE__*/React.createElement(React.Fragment, null, /*#__PURE__*/React.createElement(ShapesWidget, {
    imageRotation: imageRotation,
    zoomRatioStanding: props.page.Height / page.image.Height,
    zoomRatioLying: props.page.Width / page.image.Height,
    page: page.image
  }), mouseIsDown && /*#__PURE__*/React.createElement("div", {
    className: classes.draftShapeContainer
  }, /*#__PURE__*/React.createElement(ShapeDraft, {
    dimensions: {
      top: startY * (props.page.Height / page.image.Height),
      left: startX * (props.page.Height / page.image.Height),
      height: draftHeight * (props.page.Height / page.image.Height),
      width: draftWidth * (props.page.Height / page.image.Height)
    }
  }))), /*#__PURE__*/React.createElement("span", {
    className: classes.image
  }, imgUrl ? /*#__PURE__*/React.createElement("img", {
    src: `${imgUrl}${viewerState.showWatermark ? '?watermark=true' : ''}`,
    alt: "",
    style: {
      transition: 'transform .1s ease-in-out',
      width: `${100 * boundingBox.zoomRatio}%`,
      height: `${100 * boundingBox.zoomRatio}%`,
      transform: imageTransform
    }
  }) : /*#__PURE__*/React.createElement(CircularProgress, {
    style: {
      marginTop: '50%'
    }
  }))));
};
//# sourceMappingURL=page.js.map