import { Button, ClickAwayListener, createStyles, makeStyles, Popper } from '@material-ui/core';
import { Delete } from '@material-ui/icons';
import React, { useState } from 'react';
import { useLocalization } from "../../hooks/index.js";
const useStyles = makeStyles(theme => createStyles({
  root: {
    top: ({
      dimensions
    }) => dimensions.top,
    left: ({
      dimensions
    }) => dimensions.left,
    width: ({
      dimensions
    }) => dimensions.width,
    height: ({
      dimensions
    }) => dimensions.height,
    position: 'absolute',
    resize: ({
      permissions,
      rotationDegree
    }) => permissions.canEdit && rotationDegree === 0 ? 'both' : 'none',
    overflow: 'auto',
    backgroundColor: 'black'
  },
  button: {
    backgroundColor: theme.palette.error.light
  }
}));
/**
 * Return a styled redaction component
 * @param shape Shape attributes
 * @param permissions Permissions of the current user
 * @param dimensions Shape dimensions
 * @param zoomRatio Zoom ratio
 * @param onDragStart Function triggered on drag event
 * @param onResized Function triggered on resized event
 * @param removeShape Function triggered on delete
 * @returns styled redaction component
 */

export function ShapeRedaction({
  shape,
  permissions,
  dimensions,
  zoomRatio,
  onDragStart,
  onResized,
  removeShape,
  rotationDegree
}) {
  const classes = useStyles({
    shape,
    permissions,
    dimensions,
    zoomRatio,
    onDragStart,
    onResized,
    removeShape,
    rotationDegree
  });
  const localization = useLocalization();
  const [anchorEl, setAnchorEl] = useState(null);
  const open = Boolean(anchorEl);
  const id = open ? 'redaction-delete' : undefined;

  const onRightClick = event => {
    event.preventDefault();
    setAnchorEl(anchorEl ? null : event.currentTarget);
  };

  return /*#__PURE__*/React.createElement(React.Fragment, null, /*#__PURE__*/React.createElement("div", {
    className: classes.root,
    tabIndex: 0,
    key: `r-${shape.h}-${shape.w}`,
    draggable: permissions.canEdit,
    onDragStart: onDragStart,
    onMouseUp: onResized,
    onContextMenu: onRightClick
  }), /*#__PURE__*/React.createElement(Popper, {
    id: id,
    open: open,
    anchorEl: anchorEl,
    placement: "right-start"
  }, /*#__PURE__*/React.createElement(ClickAwayListener, {
    onClickAway: () => setAnchorEl(null)
  }, /*#__PURE__*/React.createElement(Button, {
    variant: "contained",
    className: classes.button,
    onMouseUp: () => removeShape('redactions', shape.guid),
    startIcon: /*#__PURE__*/React.createElement(Delete, {
      scale: zoomRatio
    })
  }, localization.delete))));
}
//# sourceMappingURL=shape-redaction.js.map