import { createStyles, makeStyles } from '@material-ui/core';
import React, { useCallback } from 'react';
import { useComments, useCommentState, useDocumentData, useDocumentPermissions, useViewerState } from "../../hooks/index.js";
import { applyShapeRotations, ImageUtil } from "../../services/index.js";
import { ShapeSkeleton } from "../shapes/index.js";
import { CommentMarker } from "./comment-marker.js";
const useStyles = makeStyles(() => {
  return createStyles({
    shapesContainer: {
      position: 'absolute',
      top: 0,
      left: 0,
      width: '100%',
      height: '100%',
      zIndex: 1
    }
  });
});
/**
 * Defined the component's own properties
 */

/**
 * Page widget component for displaying shapes on a page
 */
export const ShapesWidget = props => {
  var _viewerState$rotation, _viewerState$rotation2, _commentState$draft, _props$page;

  const classes = useStyles();
  const permissions = useDocumentPermissions();
  const viewerState = useViewerState();
  const {
    documentData,
    updateDocumentData
  } = useDocumentData();
  const comments = useComments();
  const commentState = useCommentState();
  const zoomRatio = props.imageRotation === 90 || props.imageRotation === 270 ? props.zoomRatioLying : props.zoomRatioStanding;
  const rotationDegree = ((_viewerState$rotation = viewerState.rotation) === null || _viewerState$rotation === void 0 ? void 0 : (_viewerState$rotation2 = _viewerState$rotation.find(rotation => rotation.pageNum === props.page.Index)) === null || _viewerState$rotation2 === void 0 ? void 0 : _viewerState$rotation2.degree) || 0;
  const visibleShapes = {
    redactions: applyShapeRotations(documentData.shapes.redactions.filter(r => r.imageIndex === props.page.Index), rotationDegree, props.page),
    highlights: applyShapeRotations(documentData.shapes.highlights.filter(r => r.imageIndex === props.page.Index), rotationDegree, props.page),
    annotations: applyShapeRotations(documentData.shapes.annotations.filter(r => r.imageIndex === props.page.Index), rotationDegree, props.page)
  };
  const visibleComments = [...comments.comments.filter(comment => comment.page === props.page.Index), ...(props.page.Index !== undefined && ((_commentState$draft = commentState.draft) === null || _commentState$draft === void 0 ? void 0 : _commentState$draft.page) === ((_props$page = props.page) === null || _props$page === void 0 ? void 0 : _props$page.Index) ? [commentState.draft] : [])];
  const removeShape = useCallback((shapeType, guid) => {
    ;
    documentData.shapes[shapeType] = documentData.shapes[shapeType].filter(s => s.guid !== guid);
    updateDocumentData(documentData);
    viewerState.updateState({
      hasChanges: true
    });
  }, [documentData, updateDocumentData, viewerState]);
  const updateShapeData = useCallback((shapeType, guid, shapeChange) => {
    ;
    documentData.shapes[shapeType] = documentData.shapes[shapeType].map(s => {
      if (s.guid === guid) {
        return { ...s,
          ...shapeChange
        };
      }

      return s;
    });
    viewerState.updateState({
      hasChanges: true
    });
    updateDocumentData(documentData);
  }, [documentData, updateDocumentData, viewerState]);
  const onDrop = useCallback(ev => {
    if (permissions.canEdit) {
      ev.preventDefault();
      const shapeData = JSON.parse(ev.dataTransfer.getData('shape'));
      const boundingBox = ev.currentTarget.getBoundingClientRect();
      updateShapeData(shapeData.type, shapeData.shape.guid, { ...shapeData.shape,
        imageIndex: props.page.Index,
        x: (ev.clientX - boundingBox.left - shapeData.offset.width) * (1 / zoomRatio),
        y: (ev.clientY - boundingBox.top - shapeData.offset.height) * (1 / zoomRatio)
      });
    }
  }, [permissions.canEdit, props.page.Index, updateShapeData, zoomRatio]);
  return /*#__PURE__*/React.createElement("div", {
    className: classes.shapesContainer,
    onDrop: onDrop,
    onDragOver: ev => ev.preventDefault()
  }, viewerState.showComments && visibleComments.length > 0 && visibleComments.map(marker => {
    var _viewerState$rotation3, _viewerState$rotation4;

    return /*#__PURE__*/React.createElement(CommentMarker, {
      isSelected: marker.id === commentState.activeCommentId,
      zoomRatio: zoomRatio,
      marker: marker,
      key: marker.id,
      rotation: ImageUtil.normalizeDegrees(((_viewerState$rotation3 = viewerState.rotation) === null || _viewerState$rotation3 === void 0 ? void 0 : (_viewerState$rotation4 = _viewerState$rotation3.find(rotation => rotation.pageNum === props.page.Index)) === null || _viewerState$rotation4 === void 0 ? void 0 : _viewerState$rotation4.degree) || 0)
    });
  }), /*#__PURE__*/React.createElement(React.Fragment, null, permissions.canHideRedaction && viewerState.showRedaction && visibleShapes.redactions.map((redaction, index) => {
    return /*#__PURE__*/React.createElement(ShapeSkeleton, {
      key: index,
      shape: redaction,
      shapeType: "redactions",
      zoomRatio: zoomRatio,
      updateShapeData: updateShapeData,
      removeShape: removeShape,
      rotationDegree: rotationDegree
    });
  }), viewerState.showShapes && visibleShapes.annotations.map((annotation, index) => {
    return /*#__PURE__*/React.createElement(ShapeSkeleton, {
      key: index,
      shape: annotation,
      shapeType: "annotations",
      zoomRatio: zoomRatio,
      updateShapeData: updateShapeData,
      removeShape: removeShape,
      rotationDegree: rotationDegree
    });
  }), viewerState.showShapes && visibleShapes.highlights.map((highlight, index) => {
    return /*#__PURE__*/React.createElement(ShapeSkeleton, {
      key: index,
      shape: highlight,
      shapeType: "highlights",
      zoomRatio: zoomRatio,
      updateShapeData: updateShapeData,
      removeShape: removeShape,
      rotationDegree: rotationDegree
    });
  })));
};
//# sourceMappingURL=shapes.js.map